# GNU Guix --- Functional package management for GNU
# Copyright © 2012, 2013, 2014, 2015, 2016 Ludovic Courtès <ludo@gnu.org>
# Copyright © 2013, 2014, 2015, 2016 Andreas Enge <andreas@enge.fr>
# Copyright © 2016 Mathieu Lirzin <mthl@gnu.org>
# Copyright © 2013, 2014, 2015, 2016 Mark H Weaver <mhw@netris.org>
# Copyright © 2016 Chris Marusich <cmmarusich@gmail.com>
# Copyright © 2016 Kei Yamashita <kei@openmailbox.org>
#
# This file is part of GNU Guix.
#
# GNU Guix is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or (at
# your option) any later version.
#
# GNU Guix is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.

# Definitions for the GNU System: package modules, patches, bootstrap
# binaries.

GNU_SYSTEM_MODULES =				\
  gnu.scm					\
  gnu/artwork.scm				\
  gnu/packages.scm				\
  gnu/packages/abduco.scm			\
  gnu/packages/abiword.scm			\
  gnu/packages/acct.scm				\
  gnu/packages/acl.scm				\
  gnu/packages/admin.scm			\
  gnu/packages/adns.scm				\
  gnu/packages/algebra.scm			\
  gnu/packages/aidc.scm				\
  gnu/packages/animation.scm			\
  gnu/packages/anthy.scm			\
  gnu/packages/apl.scm				\
  gnu/packages/apr.scm				\
  gnu/packages/asciidoc.scm			\
  gnu/packages/aspell.scm			\
  gnu/packages/attr.scm				\
  gnu/packages/audacity.scm			\
  gnu/packages/audio.scm			\
  gnu/packages/augeas.scm			\
  gnu/packages/autogen.scm			\
  gnu/packages/autotools.scm			\
  gnu/packages/avahi.scm			\
  gnu/packages/avr.scm				\
  gnu/packages/backup.scm			\
  gnu/packages/base.scm				\
  gnu/packages/bash.scm				\
  gnu/packages/bdw-gc.scm			\
  gnu/packages/bioinformatics.scm		\
  gnu/packages/bittorrent.scm			\
  gnu/packages/bison.scm			\
  gnu/packages/boost.scm			\
  gnu/packages/bootstrap.scm			\
  gnu/packages/busybox.scm			\
  gnu/packages/c.scm				\
  gnu/packages/calcurse.scm			\
  gnu/packages/ccache.scm			\
  gnu/packages/cdrom.scm			\
  gnu/packages/certs.scm			\
  gnu/packages/check.scm			\
  gnu/packages/ci.scm				\
  gnu/packages/cmake.scm			\
  gnu/packages/code.scm				\
  gnu/packages/commencement.scm			\
  gnu/packages/compression.scm			\
  gnu/packages/conkeror.scm			\
  gnu/packages/conky.scm			\
  gnu/packages/cook.scm				\
  gnu/packages/cpio.scm				\
  gnu/packages/cppi.scm				\
  gnu/packages/cross-base.scm			\
  gnu/packages/crypto.scm			\
  gnu/packages/cryptsetup.scm			\
  gnu/packages/cups.scm				\
  gnu/packages/curl.scm				\
  gnu/packages/cyrus-sasl.scm			\
  gnu/packages/databases.scm			\
  gnu/packages/datamash.scm			\
  gnu/packages/datastructures.scm		\
  gnu/packages/dav.scm				\
  gnu/packages/dc.scm				\
  gnu/packages/debug.scm			\
  gnu/packages/dejagnu.scm			\
  gnu/packages/dico.scm				\
  gnu/packages/dictionaries.scm			\
  gnu/packages/dillo.scm			\
  gnu/packages/disk.scm				\
  gnu/packages/djvu.scm				\
  gnu/packages/dns.scm				\
  gnu/packages/docbook.scm			\
  gnu/packages/docker.scm			\
  gnu/packages/doxygen.scm			\
  gnu/packages/dunst.scm			\
  gnu/packages/dvtm.scm				\
  gnu/packages/ebook.scm			\
  gnu/packages/ed.scm				\
  gnu/packages/elf.scm				\
  gnu/packages/emacs.scm			\
  gnu/packages/enchant.scm			\
  gnu/packages/engineering.scm			\
  gnu/packages/enlightenment.scm		\
  gnu/packages/fcitx.scm			\
  gnu/packages/feh.scm                          \
  gnu/packages/figlet.scm			\
  gnu/packages/file.scm				\
  gnu/packages/finance.scm			\
  gnu/packages/firmware.scm			\
  gnu/packages/fish.scm				\
  gnu/packages/flashing-tools.scm		\
  gnu/packages/flex.scm				\
  gnu/packages/fltk.scm				\
  gnu/packages/fonts.scm			\
  gnu/packages/fontutils.scm			\
  gnu/packages/freedesktop.scm			\
  gnu/packages/freeipmi.scm			\
  gnu/packages/ftp.scm				\
  gnu/packages/fribidi.scm			\
  gnu/packages/fvwm.scm				\
  gnu/packages/game-development.scm		\
  gnu/packages/games.scm			\
  gnu/packages/gawk.scm				\
  gnu/packages/gcal.scm				\
  gnu/packages/gcc.scm				\
  gnu/packages/gd.scm				\
  gnu/packages/gdb.scm				\
  gnu/packages/geeqie.scm			\
  gnu/packages/gettext.scm			\
  gnu/packages/ghostscript.scm			\
  gnu/packages/gimp.scm				\
  gnu/packages/gkrellm.scm			\
  gnu/packages/gl.scm				\
  gnu/packages/glib.scm				\
  gnu/packages/gnome.scm			\
  gnu/packages/gnu-doc.scm			\
  gnu/packages/gnucash.scm			\
  gnu/packages/gnunet.scm			\
  gnu/packages/gnupg.scm			\
  gnu/packages/gnustep.scm			\
  gnu/packages/gnuzilla.scm			\
  gnu/packages/gnu-pw-mgr.scm			\
  gnu/packages/gperf.scm			\
  gnu/packages/gprolog.scm			\
  gnu/packages/gps.scm				\
  gnu/packages/graphics.scm			\
  gnu/packages/graphviz.scm			\
  gnu/packages/groff.scm			\
  gnu/packages/grub.scm				\
  gnu/packages/grue-hunter.scm			\
  gnu/packages/gsasl.scm			\
  gnu/packages/gstreamer.scm			\
  gnu/packages/gtk.scm				\
  gnu/packages/guile.scm			\
  gnu/packages/guile-wm.scm			\
  gnu/packages/gv.scm				\
  gnu/packages/gxmessage.scm			\
  gnu/packages/haskell.scm			\
  gnu/packages/hugs.scm				\
  gnu/packages/hurd.scm				\
  gnu/packages/ibus.scm				\
  gnu/packages/icu4c.scm			\
  gnu/packages/idutils.scm			\
  gnu/packages/image.scm			\
  gnu/packages/imagemagick.scm			\
  gnu/packages/indent.scm			\
  gnu/packages/inklingreader.scm		\
  gnu/packages/inkscape.scm			\
  gnu/packages/irc.scm  			\
  gnu/packages/iso-codes.scm			\
  gnu/packages/java.scm				\
  gnu/packages/jemalloc.scm			\
  gnu/packages/jrnl.scm				\
  gnu/packages/julia.scm			\
  gnu/packages/kde.scm              \
  gnu/packages/kde-frameworks.scm		\
  gnu/packages/key-mon.scm			\
  gnu/packages/kodi.scm				\
  gnu/packages/language.scm			\
  gnu/packages/ldc.scm				\
  gnu/packages/lego.scm				\
  gnu/packages/less.scm				\
  gnu/packages/lesstif.scm			\
  gnu/packages/libcanberra.scm			\
  gnu/packages/libdaemon.scm			\
  gnu/packages/libedit.scm			\
  gnu/packages/libevent.scm			\
  gnu/packages/libffcall.scm			\
  gnu/packages/libffi.scm			\
  gnu/packages/libftdi.scm			\
  gnu/packages/calendar.scm			\
  gnu/packages/libidn.scm			\
  gnu/packages/libphidget.scm			\
  gnu/packages/libreoffice.scm			\
  gnu/packages/libsigsegv.scm			\
  gnu/packages/libunistring.scm			\
  gnu/packages/libusb.scm			\
  gnu/packages/libunwind.scm			\
  gnu/packages/libupnp.scm			\
  gnu/packages/lightning.scm			\
  gnu/packages/links.scm			\
  gnu/packages/linux.scm			\
  gnu/packages/lirc.scm				\
  gnu/packages/lisp.scm				\
  gnu/packages/llvm.scm				\
  gnu/packages/lout.scm				\
  gnu/packages/lsh.scm				\
  gnu/packages/lsof.scm				\
  gnu/packages/lua.scm				\
  gnu/packages/lxde.scm				\
  gnu/packages/lxqt.scm				\
  gnu/packages/lynx.scm				\
  gnu/packages/m4.scm				\
  gnu/packages/machine-learning.scm		\
  gnu/packages/man.scm				\
  gnu/packages/mail.scm				\
  gnu/packages/make-bootstrap.scm		\
  gnu/packages/markdown.scm			\
  gnu/packages/marst.scm			\
  gnu/packages/mate.scm             \
  gnu/packages/maths.scm			\
  gnu/packages/mc.scm				\
  gnu/packages/mcrypt.scm			\
  gnu/packages/messaging.scm			\
  gnu/packages/mg.scm				\
  gnu/packages/mit-krb5.scm			\
  gnu/packages/moe.scm				\
  gnu/packages/moreutils.scm			\
  gnu/packages/mpd.scm				\
  gnu/packages/mp3.scm				\
  gnu/packages/mpi.scm				\
  gnu/packages/multiprecision.scm		\
  gnu/packages/music.scm			\
  gnu/packages/mtools.scm			\
  gnu/packages/nano.scm				\
  gnu/packages/ncdu.scm				\
  gnu/packages/ncurses.scm			\
  gnu/packages/netpbm.scm			\
  gnu/packages/nettle.scm			\
  gnu/packages/networking.scm			\
  gnu/packages/ninja.scm			\
  gnu/packages/node.scm				\
  gnu/packages/noweb.scm			\
  gnu/packages/ntp.scm				\
  gnu/packages/nutrition.scm			\
  gnu/packages/nvi.scm				\
  gnu/packages/ocaml.scm			\
  gnu/packages/ocr.scm				\
  gnu/packages/onc-rpc.scm			\
  gnu/packages/openbox.scm			\
  gnu/packages/openldap.scm			\
  gnu/packages/openstack.scm			\
  gnu/packages/orpheus.scm			\
  gnu/packages/ots.scm				\
  gnu/packages/owncloud.scm			\
  gnu/packages/package-management.scm		\
  gnu/packages/parallel.scm			\
  gnu/packages/password-utils.scm		\
  gnu/packages/patchutils.scm			\
  gnu/packages/pciutils.scm			\
  gnu/packages/pcre.scm				\
  gnu/packages/pdf.scm				\
  gnu/packages/pem.scm				\
  gnu/packages/perl.scm				\
  gnu/packages/photo.scm			\
  gnu/packages/pkg-config.scm			\
  gnu/packages/plotutils.scm			\
  gnu/packages/polkit.scm			\
  gnu/packages/popt.scm				\
  gnu/packages/pth.scm				\
  gnu/packages/pulseaudio.scm			\
  gnu/packages/pumpio.scm			\
  gnu/packages/pretty-print.scm			\
  gnu/packages/protobuf.scm			\
  gnu/packages/pv.scm				\
  gnu/packages/python.scm			\
  gnu/packages/qemu.scm				\
  gnu/packages/qt.scm				\
  gnu/packages/ragel.scm			\
  gnu/packages/ratpoison.scm			\
  gnu/packages/rc.scm				\
  gnu/packages/rdesktop.scm			\
  gnu/packages/rdf.scm				\
  gnu/packages/readline.scm			\
  gnu/packages/rrdtool.scm			\
  gnu/packages/rsync.scm			\
  gnu/packages/ruby.scm				\
  gnu/packages/rush.scm				\
  gnu/packages/samba.scm			\
  gnu/packages/sawfish.scm			\
  gnu/packages/scanner.scm			\
  gnu/packages/scheme.scm			\
  gnu/packages/screen.scm			\
  gnu/packages/scribus.scm			\
  gnu/packages/sdl.scm				\
  gnu/packages/search.scm			\
  gnu/packages/serialization.scm		\
  gnu/packages/serveez.scm			\
  gnu/packages/shishi.scm			\
  gnu/packages/skarnet.scm			\
  gnu/packages/skribilo.scm			\
  gnu/packages/slang.scm			\
  gnu/packages/slim.scm				\
  gnu/packages/smalltalk.scm			\
  gnu/packages/ssh.scm				\
  gnu/packages/stalonetray.scm			\
  gnu/packages/statistics.scm			\
  gnu/packages/suckless.scm			\
  gnu/packages/swig.scm				\
  gnu/packages/sxiv.scm				\
  gnu/packages/synergy.scm			\
  gnu/packages/task-management.scm		\
  gnu/packages/tbb.scm				\
  gnu/packages/tcl.scm				\
  gnu/packages/tcsh.scm				\
  gnu/packages/telephony.scm			\
  gnu/packages/terminals.scm			\
  gnu/packages/texinfo.scm			\
  gnu/packages/texlive.scm			\
  gnu/packages/textutils.scm			\
  gnu/packages/time.scm				\
  gnu/packages/tls.scm				\
  gnu/packages/tmux.scm				\
  gnu/packages/tor.scm				\
  gnu/packages/tre.scm				\
  gnu/packages/tv.scm				\
  gnu/packages/unrtf.scm			\
  gnu/packages/upnp.scm				\
  gnu/packages/uucp.scm				\
  gnu/packages/valgrind.scm			\
  gnu/packages/version-control.scm		\
  gnu/packages/video.scm			\
  gnu/packages/vim.scm				\
  gnu/packages/vpn.scm				\
  gnu/packages/vtk.scm				\
  gnu/packages/w3m.scm				\
  gnu/packages/wdiff.scm			\
  gnu/packages/web.scm				\
  gnu/packages/webkit.scm			\
  gnu/packages/wget.scm				\
  gnu/packages/wicd.scm				\
  gnu/packages/wine.scm				\
  gnu/packages/wm.scm				\
  gnu/packages/wordnet.scm			\
  gnu/packages/wv.scm				\
  gnu/packages/wxwidgets.scm			\
  gnu/packages/xfig.scm				\
  gnu/packages/xiph.scm				\
  gnu/packages/xml.scm				\
  gnu/packages/xnee.scm				\
  gnu/packages/xdisorg.scm			\
  gnu/packages/xorg.scm				\
  gnu/packages/xfce.scm				\
  gnu/packages/yasm.scm				\
  gnu/packages/yubico.scm			\
  gnu/packages/zile.scm				\
  gnu/packages/zip.scm				\
  gnu/packages/zsh.scm				\
						\
  gnu/services.scm				\
  gnu/services/avahi.scm			\
  gnu/services/base.scm				\
  gnu/services/databases.scm			\
  gnu/services/dbus.scm				\
  gnu/services/desktop.scm			\
  gnu/services/lirc.scm				\
  gnu/services/mail.scm				\
  gnu/services/networking.scm			\
  gnu/services/shepherd.scm			\
  gnu/services/herd.scm				\
  gnu/services/ssh.scm				\
  gnu/services/web.scm				\
  gnu/services/xorg.scm				\
						\
  gnu/system.scm				\
  gnu/system/file-systems.scm			\
  gnu/system/grub.scm				\
  gnu/system/install.scm			\
  gnu/system/linux-container.scm		\
  gnu/system/linux-initrd.scm			\
  gnu/system/locale.scm				\
  gnu/system/mapped-devices.scm			\
  gnu/system/nss.scm				\
  gnu/system/pam.scm				\
  gnu/system/shadow.scm				\
  gnu/system/vm.scm				\
						\
  gnu/build/activation.scm			\
  gnu/build/file-systems.scm			\
  gnu/build/install.scm				\
  gnu/build/linux-boot.scm			\
  gnu/build/linux-container.scm			\
  gnu/build/linux-initrd.scm			\
  gnu/build/linux-modules.scm			\
  gnu/build/vm.scm


patchdir = $(guilemoduledir)/gnu/packages/patches
dist_patch_DATA =						\
  gnu/packages/patches/4store-fix-buildsystem.patch		\
  gnu/packages/patches/abiword-explictly-cast-bools.patch	\
  gnu/packages/patches/abiword-wmf-version-lookup-fix.patch	\
  gnu/packages/patches/acl-hurd-path-max.patch			\
  gnu/packages/patches/aegis-constness-error.patch         	\
  gnu/packages/patches/aegis-perl-tempdir1.patch           	\
  gnu/packages/patches/aegis-perl-tempdir2.patch           	\
  gnu/packages/patches/aegis-test-fixup-1.patch            	\
  gnu/packages/patches/aegis-test-fixup-2.patch            	\
  gnu/packages/patches/agg-am_c_prototype.patch			\
  gnu/packages/patches/alsa-lib-mips-atomic-fix.patch		\
  gnu/packages/patches/apr-skip-getservbyname-test.patch	\
  gnu/packages/patches/arb-ldconfig.patch			\
  gnu/packages/patches/ath9k-htc-firmware-binutils.patch	\
  gnu/packages/patches/ath9k-htc-firmware-gcc.patch		\
  gnu/packages/patches/ath9k-htc-firmware-objcopy.patch		\
  gnu/packages/patches/audacity-fix-ffmpeg-binding.patch	\
  gnu/packages/patches/automake-skip-amhello-tests.patch	\
  gnu/packages/patches/automake-regexp-syntax.patch		\
  gnu/packages/patches/avahi-localstatedir.patch		\
  gnu/packages/patches/avidemux-install-to-lib.patch		\
  gnu/packages/patches/avrdude-fix-libusb.patch			\
  gnu/packages/patches/bash-completion-directories.patch	\
  gnu/packages/patches/bigloo-gc-shebangs.patch			\
  gnu/packages/patches/binutils-ld-new-dtags.patch		\
  gnu/packages/patches/binutils-loongson-workaround.patch	\
  gnu/packages/patches/byobu-writable-status.patch		\
  gnu/packages/patches/calibre-drop-unrar.patch			\
  gnu/packages/patches/calibre-no-updates-dialog.patch		\
  gnu/packages/patches/cdparanoia-fpic.patch			\
  gnu/packages/patches/chmlib-inttypes.patch			\
  gnu/packages/patches/clang-libc-search-path.patch		\
  gnu/packages/patches/clucene-pkgconfig.patch			\
  gnu/packages/patches/cmake-fix-tests.patch			\
  gnu/packages/patches/cpio-gets-undeclared.patch		\
  gnu/packages/patches/cpio-CVE-2016-2037.patch			\
  gnu/packages/patches/cpufrequtils-fix-aclocal.patch		\
  gnu/packages/patches/crda-optional-gcrypt.patch		\
  gnu/packages/patches/crossmap-allow-system-pysam.patch	\
  gnu/packages/patches/csound-header-ordering.patch		\
  gnu/packages/patches/cssc-gets-undeclared.patch               \
  gnu/packages/patches/cssc-missing-include.patch               \
  gnu/packages/patches/clucene-contribs-lib.patch               \
  gnu/packages/patches/cursynth-wave-rand.patch			\
  gnu/packages/patches/dbus-helper-search-path.patch		\
  gnu/packages/patches/dealii-p4est-interface.patch		\
  gnu/packages/patches/devil-fix-libpng.patch			\
  gnu/packages/patches/dico-libtool-deterministic.patch		\
  gnu/packages/patches/diffutils-gets-undeclared.patch		\
  gnu/packages/patches/dfu-programmer-fix-libusb.patch		\
  gnu/packages/patches/doxygen-test.patch			\
  gnu/packages/patches/duplicity-piped-password.patch		\
  gnu/packages/patches/duplicity-test_selection-tmp.patch	\
  gnu/packages/patches/elfutils-tests-ptrace.patch		\
  gnu/packages/patches/einstein-build.patch			\
  gnu/packages/patches/emacs-constants-lisp-like.patch		\
  gnu/packages/patches/emacs-exec-path.patch			\
  gnu/packages/patches/emacs-scheme-complete-scheme-r5rs-info.patch	\
  gnu/packages/patches/emacs-source-date-epoch.patch		\
  gnu/packages/patches/eudev-rules-directory.patch		\
  gnu/packages/patches/evilwm-lost-focus-bug.patch		\
  gnu/packages/patches/expat-CVE-2015-1283.patch		\
  gnu/packages/patches/fastcap-mulGlobal.patch			\
  gnu/packages/patches/fastcap-mulSetup.patch			\
  gnu/packages/patches/fasthenry-spAllocate.patch		\
  gnu/packages/patches/fasthenry-spBuild.patch			\
  gnu/packages/patches/fasthenry-spUtils.patch			\
  gnu/packages/patches/fasthenry-spSolve.patch			\
  gnu/packages/patches/fasthenry-spFactor.patch			\
  gnu/packages/patches/findutils-localstatedir.patch		\
  gnu/packages/patches/findutils-test-xargs.patch		\
  gnu/packages/patches/flashrom-use-libftdi1.patch		\
  gnu/packages/patches/flint-ldconfig.patch			\
  gnu/packages/patches/fltk-shared-lib-defines.patch		\
  gnu/packages/patches/fltk-xfont-on-demand.patch		\
  gnu/packages/patches/fontforge-svg-modtime.patch		\
  gnu/packages/patches/fossil-test-fixes.patch			\
  gnu/packages/patches/freeimage-CVE-2015-0852.patch		\
  gnu/packages/patches/gawk-fts-test.patch			\
  gnu/packages/patches/gawk-shell.patch				\
  gnu/packages/patches/gcc-arm-link-spec-fix.patch		\
  gnu/packages/patches/gcc-cross-environment-variables.patch	\
  gnu/packages/patches/gcc-libvtv-runpath.patch			\
  gnu/packages/patches/gcc-5.0-libvtv-runpath.patch		\
  gnu/packages/patches/geoclue-config.patch			\
  gnu/packages/patches/ghostscript-CVE-2015-3228.patch		\
  gnu/packages/patches/ghostscript-runpath.patch		\
  gnu/packages/patches/glib-networking-ssl-cert-file.patch	\
  gnu/packages/patches/glib-tests-desktop.patch			\
  gnu/packages/patches/glib-tests-homedir.patch			\
  gnu/packages/patches/glib-tests-prlimit.patch			\
  gnu/packages/patches/glib-tests-timer.patch			\
  gnu/packages/patches/glib-tests-gapplication.patch		\
  gnu/packages/patches/glibc-CVE-2015-7547.patch		\
  gnu/packages/patches/glibc-bootstrap-system.patch		\
  gnu/packages/patches/glibc-hurd-extern-inline.patch		\
  gnu/packages/patches/glibc-ldd-x86_64.patch			\
  gnu/packages/patches/glibc-locales.patch			\
  gnu/packages/patches/glibc-locale-incompatibility.patch	\
  gnu/packages/patches/glibc-o-largefile.patch			\
  gnu/packages/patches/glibc-versioned-locpath.patch		\
  gnu/packages/patches/gmp-arm-asm-nothumb.patch		\
  gnu/packages/patches/gmp-faulty-test.patch			\
  gnu/packages/patches/gnucash-price-quotes-perl.patch		\
  gnu/packages/patches/gobject-introspection-absolute-shlib-path.patch \
  gnu/packages/patches/gobject-introspection-cc.patch		\
  gnu/packages/patches/gobject-introspection-girepository.patch	\
  gnu/packages/patches/grep-timing-sensitive-test.patch		\
  gnu/packages/patches/grub-CVE-2015-8370.patch			\
  gnu/packages/patches/grub-gets-undeclared.patch		\
  gnu/packages/patches/grub-freetype.patch			\
  gnu/packages/patches/guile-1.8-cpp-4.5.patch			\
  gnu/packages/patches/guile-arm-fixes.patch			\
  gnu/packages/patches/guile-default-utf8.patch			\
  gnu/packages/patches/guile-linux-syscalls.patch		\
  gnu/packages/patches/guile-present-coding.patch		\
  gnu/packages/patches/guile-relocatable.patch			\
  gnu/packages/patches/guile-rsvg-pkgconfig.patch		\
  gnu/packages/patches/gtk2-respect-GUIX_GTK2_PATH.patch	\
  gnu/packages/patches/gtk3-respect-GUIX_GTK3_PATH.patch	\
  gnu/packages/patches/gtkglext-disable-disable-deprecated.patch \
  gnu/packages/patches/hop-bigloo-4.0b.patch			\
  gnu/packages/patches/hop-linker-flags.patch			\
  gnu/packages/patches/hydra-automake-1.15.patch		\
  gnu/packages/patches/hydra-disable-darcs-test.patch		\
  gnu/packages/patches/icecat-avoid-bundled-includes.patch	\
  gnu/packages/patches/icecat-re-enable-DHE-cipher-suites.patch	\
  gnu/packages/patches/icecat-update-bundled-graphite2.patch	\
  gnu/packages/patches/icecat-CVE-2016-2805.patch		\
  gnu/packages/patches/icecat-CVE-2016-2807-pt1.patch		\
  gnu/packages/patches/icecat-CVE-2016-2807-pt2.patch		\
  gnu/packages/patches/icecat-CVE-2016-2807-pt3.patch		\
  gnu/packages/patches/icecat-CVE-2016-2807-pt4.patch		\
  gnu/packages/patches/icecat-CVE-2016-2807-pt5.patch		\
  gnu/packages/patches/icecat-CVE-2016-2808.patch		\
  gnu/packages/patches/icecat-CVE-2016-2814.patch		\
  gnu/packages/patches/icu4c-CVE-2014-6585.patch		\
  gnu/packages/patches/icu4c-CVE-2015-1270.patch		\
  gnu/packages/patches/icu4c-CVE-2015-4760.patch		\
  gnu/packages/patches/ilmbase-fix-tests.patch			\
  gnu/packages/patches/irrlicht-mesa-10.patch			\
  gnu/packages/patches/jasper-CVE-2007-2721.patch		\
  gnu/packages/patches/jasper-CVE-2008-3520.patch		\
  gnu/packages/patches/jasper-CVE-2008-3522.patch		\
  gnu/packages/patches/jasper-CVE-2011-4516-and-CVE-2011-4517.patch \
  gnu/packages/patches/jasper-CVE-2014-8137.patch		\
  gnu/packages/patches/jasper-CVE-2014-8138.patch		\
  gnu/packages/patches/jasper-CVE-2014-8157.patch		\
  gnu/packages/patches/jasper-CVE-2014-8158.patch		\
  gnu/packages/patches/jasper-CVE-2014-9029.patch		\
  gnu/packages/patches/jasper-CVE-2016-1577.patch		\
  gnu/packages/patches/jasper-CVE-2016-1867.patch		\
  gnu/packages/patches/jasper-CVE-2016-2089.patch		\
  gnu/packages/patches/jasper-CVE-2016-2116.patch		\
  gnu/packages/patches/jbig2dec-ignore-testtest.patch		\
  gnu/packages/patches/kmod-module-directory.patch		\
  gnu/packages/patches/ldc-disable-tests.patch			\
  gnu/packages/patches/lftp-dont-save-unknown-host-fingerprint.patch \
  gnu/packages/patches/liba52-enable-pic.patch			\
  gnu/packages/patches/liba52-link-with-libm.patch		\
  gnu/packages/patches/liba52-set-soname.patch			\
  gnu/packages/patches/liba52-use-mtune-not-mcpu.patch		\
  gnu/packages/patches/libarchive-bsdtar-test.patch		\
  gnu/packages/patches/libarchive-CVE-2013-0211.patch		\
  gnu/packages/patches/libarchive-fix-lzo-test-case.patch	\
  gnu/packages/patches/libarchive-mtree-filename-length-fix.patch \
  gnu/packages/patches/libbonobo-activation-test-race.patch	\
  gnu/packages/patches/libcanberra-sound-theme-freedesktop.patch \
  gnu/packages/patches/libcmis-fix-test-onedrive.patch		\
  gnu/packages/patches/libdrm-symbol-check.patch		\
  gnu/packages/patches/libevent-dns-tests.patch			\
  gnu/packages/patches/libextractor-ffmpeg-3.patch		\
  gnu/packages/patches/libmtp-devices.patch			\
  gnu/packages/patches/liboop-mips64-deplibs-fix.patch		\
  gnu/packages/patches/libotr-test-auth-fix.patch		\
  gnu/packages/patches/liblxqt-include.patch			\
  gnu/packages/patches/libmad-armv7-thumb-pt1.patch		\
  gnu/packages/patches/libmad-armv7-thumb-pt2.patch		\
  gnu/packages/patches/libmad-frame-length.patch		\
  gnu/packages/patches/libmad-mips-newgcc.patch			\
  gnu/packages/patches/libssh-0.6.5-CVE-2016-0739.patch		\
  gnu/packages/patches/libtheora-config-guess.patch		\
  gnu/packages/patches/libtiff-CVE-2015-8665+CVE-2015-8683.patch \
  gnu/packages/patches/libtiff-oob-accesses-in-decode.patch	\
  gnu/packages/patches/libtiff-oob-write-in-nextdecode.patch	\
  gnu/packages/patches/libtool-skip-tests2.patch		\
  gnu/packages/patches/libunwind-CVE-2015-3239.patch		\
  gnu/packages/patches/libwmf-CAN-2004-0941.patch		\
  gnu/packages/patches/libwmf-CVE-2006-3376.patch		\
  gnu/packages/patches/libwmf-CVE-2007-0455.patch		\
  gnu/packages/patches/libwmf-CVE-2007-2756.patch		\
  gnu/packages/patches/libwmf-CVE-2007-3472.patch		\
  gnu/packages/patches/libwmf-CVE-2007-3473.patch		\
  gnu/packages/patches/libwmf-CVE-2007-3477.patch		\
  gnu/packages/patches/libwmf-CVE-2009-1364.patch		\
  gnu/packages/patches/libwmf-CVE-2009-3546.patch		\
  gnu/packages/patches/libwmf-CVE-2015-0848+CVE-2015-4588.patch	\
  gnu/packages/patches/libwmf-CVE-2015-4695.patch		\
  gnu/packages/patches/libwmf-CVE-2015-4696.patch		\
  gnu/packages/patches/libxslt-CVE-2015-7995.patch		\
  gnu/packages/patches/lirc-localstatedir.patch			\
  gnu/packages/patches/libpthread-glibc-preparation.patch	\
  gnu/packages/patches/lm-sensors-hwmon-attrs.patch		\
  gnu/packages/patches/lua-pkgconfig.patch                      \
  gnu/packages/patches/lua51-liblua-so.patch                    \
  gnu/packages/patches/lua52-liblua-so.patch                    \
  gnu/packages/patches/luajit-no_ldconfig.patch			\
  gnu/packages/patches/luajit-symlinks.patch			\
  gnu/packages/patches/luit-posix.patch				\
  gnu/packages/patches/m4-gets-undeclared.patch			\
  gnu/packages/patches/make-impure-dirs.patch			\
  gnu/packages/patches/mars-install.patch			\
  gnu/packages/patches/mars-sfml-2.3.patch			\
  gnu/packages/patches/matplotlib-setupext-tk.patch		\
  gnu/packages/patches/maxima-defsystem-mkdir.patch		\
  gnu/packages/patches/mcron-install.patch			\
  gnu/packages/patches/mdadm-gcc-4.9-fix.patch			\
  gnu/packages/patches/mhash-keygen-test-segfault.patch		\
  gnu/packages/patches/mit-krb5-CVE-2015-8629.patch		\
  gnu/packages/patches/mit-krb5-CVE-2015-8630.patch		\
  gnu/packages/patches/mit-krb5-CVE-2015-8631.patch		\
  gnu/packages/patches/mit-krb5-init-context-null-spnego.patch	\
  gnu/packages/patches/mpc123-initialize-ao.patch		\
  gnu/packages/patches/mplayer2-theora-fix.patch		\
  gnu/packages/patches/module-init-tools-moduledir.patch	\
  gnu/packages/patches/mumps-build-parallelism.patch		\
  gnu/packages/patches/mupen64plus-ui-console-notice.patch	\
  gnu/packages/patches/mutt-store-references.patch		\
  gnu/packages/patches/net-tools-bitrot.patch			\
  gnu/packages/patches/ngircd-handle-zombies.patch		\
  gnu/packages/patches/ngircd-no-dns-in-tests.patch		\
  gnu/packages/patches/ninja-tests.patch			\
  gnu/packages/patches/ninja-zero-mtime.patch			\
  gnu/packages/patches/nss-pkgconfig.patch			\
  gnu/packages/patches/nvi-assume-preserve-path.patch		\
  gnu/packages/patches/nvi-dbpagesize-binpower.patch		\
  gnu/packages/patches/nvi-db4.patch				\
  gnu/packages/patches/ocaml-CVE-2015-8869.patch		\
  gnu/packages/patches/ocaml-findlib-make-install.patch	\
  gnu/packages/patches/openexr-missing-samples.patch		\
  gnu/packages/patches/openimageio-boost-1.60.patch		\
  gnu/packages/patches/openjpeg-CVE-2015-6581.patch		\
  gnu/packages/patches/openjpeg-use-after-free-fix.patch	\
  gnu/packages/patches/openssh-CVE-2015-8325.patch		\
  gnu/packages/patches/openssl-runpath.patch			\
  gnu/packages/patches/openssl-c-rehash-in.patch		\
  gnu/packages/patches/orpheus-cast-errors-and-includes.patch	\
  gnu/packages/patches/ots-no-include-missing-file.patch	\
  gnu/packages/patches/patchelf-page-size.patch			\
  gnu/packages/patches/patchelf-rework-for-arm.patch		\
  gnu/packages/patches/patchutils-xfail-gendiff-tests.patch	\
  gnu/packages/patches/patch-hurd-path-max.patch		\
  gnu/packages/patches/pcre-CVE-2016-3191.patch			\
  gnu/packages/patches/perl-CVE-2015-8607.patch			\
  gnu/packages/patches/perl-CVE-2016-2381.patch			\
  gnu/packages/patches/perl-autosplit-default-time.patch	\
  gnu/packages/patches/perl-deterministic-ordering.patch	\
  gnu/packages/patches/perl-finance-quote-unuse-mozilla-ca.patch \
  gnu/packages/patches/perl-gd-options-passthrough-and-fontconfig.patch \
  gnu/packages/patches/perl-io-socket-ssl-openssl-1.0.2f-fix.patch \
  gnu/packages/patches/perl-net-amazon-s3-moose-warning.patch	\
  gnu/packages/patches/perl-net-ssleay-disable-ede-test.patch	\
  gnu/packages/patches/perl-no-build-time.patch			\
  gnu/packages/patches/perl-no-sys-dirs.patch			\
  gnu/packages/patches/perl-module-pluggable-search.patch	\
  gnu/packages/patches/perl-source-date-epoch.patch		\
  gnu/packages/patches/pidgin-add-search-path.patch		\
  gnu/packages/patches/pinball-const-fix.patch			\
  gnu/packages/patches/pinball-cstddef.patch			\
  gnu/packages/patches/pinball-missing-separators.patch		\
  gnu/packages/patches/pinball-src-deps.patch			\
  gnu/packages/patches/pinball-system-ltdl.patch		\
  gnu/packages/patches/pingus-sdl-libs-config.patch		\
  gnu/packages/patches/plink-1.07-unclobber-i.patch		\
  gnu/packages/patches/plotutils-libpng-jmpbuf.patch		\
  gnu/packages/patches/polkit-drop-test.patch			\
  gnu/packages/patches/poppler-CVE-2015-8868.patch		\
  gnu/packages/patches/portaudio-audacity-compat.patch		\
  gnu/packages/patches/portmidi-modular-build.patch		\
  gnu/packages/patches/procmail-ambiguous-getline-debian.patch  \
  gnu/packages/patches/pt-scotch-build-parallelism.patch	\
  gnu/packages/patches/pulseaudio-fix-mult-test.patch		\
  gnu/packages/patches/pulseaudio-longer-test-timeout.patch	\
  gnu/packages/patches/pycairo-wscript.patch			\
  gnu/packages/patches/pybugz-encode-error.patch		\
  gnu/packages/patches/pybugz-stty.patch			\
  gnu/packages/patches/pygpgme-disable-problematic-tests.patch  \
  gnu/packages/patches/pyqt-configure.patch			\
  gnu/packages/patches/python-2-deterministic-build-info.patch	\
  gnu/packages/patches/python-2.7-search-paths.patch		\
  gnu/packages/patches/python-2.7-source-date-epoch.patch	\
  gnu/packages/patches/python-3-deterministic-build-info.patch	\
  gnu/packages/patches/python-3-search-paths.patch		\
  gnu/packages/patches/python-disable-ssl-test.patch		\
  gnu/packages/patches/python-fix-tests.patch			\
  gnu/packages/patches/python-ipython-inputhook-ctype.patch	\
  gnu/packages/patches/python-rarfile-fix-tests.patch		\
  gnu/packages/patches/python2-rdflib-drop-sparqlwrapper.patch	\
  gnu/packages/patches/python-configobj-setuptools.patch	\
  gnu/packages/patches/python-paste-remove-website-test.patch	\
  gnu/packages/patches/python-paste-remove-timing-test.patch	\
  gnu/packages/patches/python2-pygobject-2-gi-info-type-error-domain.patch \
  gnu/packages/patches/python-pandas-fix-tslib-test-failure.patch \
  gnu/packages/patches/qemu-CVE-2015-8558.patch			\
  gnu/packages/patches/qemu-CVE-2015-8567.patch			\
  gnu/packages/patches/qemu-CVE-2015-8613.patch			\
  gnu/packages/patches/qemu-CVE-2015-8619.patch			\
  gnu/packages/patches/qemu-CVE-2015-8701.patch			\
  gnu/packages/patches/qemu-CVE-2015-8743.patch			\
  gnu/packages/patches/qemu-CVE-2016-1568.patch			\
  gnu/packages/patches/qemu-CVE-2016-1922.patch			\
  gnu/packages/patches/qemu-CVE-2016-1981.patch			\
  gnu/packages/patches/qemu-CVE-2016-2197.patch			\
  gnu/packages/patches/qemu-usb-ehci-oob-read.patch		\
  gnu/packages/patches/qemu-virtio-9p-use-accessor-to-get-thread-pool.patch \
  gnu/packages/patches/qt4-ldflags.patch			\
  gnu/packages/patches/ratpoison-shell.patch			\
  gnu/packages/patches/readline-link-ncurses.patch		\
  gnu/packages/patches/ripperx-missing-file.patch		\
  gnu/packages/patches/rsem-makefile.patch			\
  gnu/packages/patches/ruby-symlinkfix.patch                    \
  gnu/packages/patches/sed-hurd-path-max.patch			\
  gnu/packages/patches/scheme48-tests.patch			\
  gnu/packages/patches/scotch-test-threading.patch		\
  gnu/packages/patches/sdl-libx11-1.6.patch			\
  gnu/packages/patches/serf-comment-style-fix.patch		\
  gnu/packages/patches/serf-deflate-buckets-test-fix.patch	\
  gnu/packages/patches/slim-session.patch			\
  gnu/packages/patches/slim-config.patch			\
  gnu/packages/patches/slim-sigusr1.patch			\
  gnu/packages/patches/slurm-configure-remove-nonfree-contribs.patch \
  gnu/packages/patches/soprano-find-clucene.patch		\
  gnu/packages/patches/sudo-CVE-2015-5602.patch			\
  gnu/packages/patches/superlu-dist-scotchmetis.patch		\
  gnu/packages/patches/synfig-build-fix.patch			\
  gnu/packages/patches/tar-d_ino_in_dirent-fix.patch		\
  gnu/packages/patches/tar-skip-unreliable-tests.patch		\
  gnu/packages/patches/tcl-mkindex-deterministic.patch		\
  gnu/packages/patches/tclxml-3.2-install.patch			\
  gnu/packages/patches/tcsh-fix-autotest.patch			\
  gnu/packages/patches/texi2html-document-encoding.patch	\
  gnu/packages/patches/texi2html-i18n.patch			\
  gnu/packages/patches/tidy-CVE-2015-5522+5523.patch		\
  gnu/packages/patches/tinyxml-use-stl.patch			\
  gnu/packages/patches/tk-find-library.patch			\
  gnu/packages/patches/ttf2eot-cstddef.patch			\
  gnu/packages/patches/ttfautohint-source-date-epoch.patch	\
  gnu/packages/patches/tophat-build-with-later-seqan.patch	\
  gnu/packages/patches/torsocks-dns-test.patch			\
  gnu/packages/patches/tvtime-gcc41.patch			\
  gnu/packages/patches/tvtime-pngoutput.patch			\
  gnu/packages/patches/tvtime-videodev2.patch			\
  gnu/packages/patches/tvtime-xmltv.patch			\
  gnu/packages/patches/unzip-CVE-2014-8139.patch		\
  gnu/packages/patches/unzip-CVE-2014-8140.patch		\
  gnu/packages/patches/unzip-CVE-2014-8141.patch		\
  gnu/packages/patches/unzip-CVE-2014-9636.patch		\
  gnu/packages/patches/unzip-CVE-2015-7696.patch		\
  gnu/packages/patches/unzip-CVE-2015-7697.patch		\
  gnu/packages/patches/unzip-allow-greater-hostver-values.patch	\
  gnu/packages/patches/unzip-attribs-overflow.patch		\
  gnu/packages/patches/unzip-overflow-on-invalid-input.patch	\
  gnu/packages/patches/unzip-format-secure.patch		\
  gnu/packages/patches/unzip-initialize-symlink-flag.patch	\
  gnu/packages/patches/unzip-overflow-long-fsize.patch		\
  gnu/packages/patches/unzip-remove-build-date.patch		\
  gnu/packages/patches/util-linux-tests.patch			\
  gnu/packages/patches/upower-builddir.patch			\
  gnu/packages/patches/valgrind-enable-arm.patch		\
  gnu/packages/patches/vorbis-tools-CVE-2015-6749.patch		\
  gnu/packages/patches/vpnc-script.patch			\
  gnu/packages/patches/vtk-mesa-10.patch			\
  gnu/packages/patches/w3m-libgc.patch				\
  gnu/packages/patches/w3m-force-ssl_verify_server-on.patch	\
  gnu/packages/patches/w3m-disable-sslv2-and-sslv3.patch	\
  gnu/packages/patches/w3m-disable-weak-ciphers.patch		\
  gnu/packages/patches/weechat-python.patch			\
  gnu/packages/patches/weex-vacopy.patch			\
  gnu/packages/patches/wicd-bitrate-none-fix.patch		\
  gnu/packages/patches/wicd-get-selected-profile-fix.patch	\
  gnu/packages/patches/wicd-urwid-1.3.patch			\
  gnu/packages/patches/wicd-wpa2-ttls.patch			\
  gnu/packages/patches/wmctrl-64-fix.patch			\
  gnu/packages/patches/woff2-libbrotli.patch			\
  gnu/packages/patches/wpa-supplicant-CVE-2015-5310.patch	\
  gnu/packages/patches/wpa-supplicant-CVE-2015-5314.patch	\
  gnu/packages/patches/wpa-supplicant-CVE-2015-5315.patch	\
  gnu/packages/patches/wpa-supplicant-CVE-2015-5316.patch	\
  gnu/packages/patches/wpa-supplicant-CVE-2016-4476.patch	\
  gnu/packages/patches/wpa-supplicant-CVE-2016-4477-pt1.patch	\
  gnu/packages/patches/wpa-supplicant-CVE-2016-4477-pt2.patch	\
  gnu/packages/patches/wpa-supplicant-CVE-2016-4477-pt3.patch	\
  gnu/packages/patches/wpa-supplicant-CVE-2016-4477-pt4.patch	\
  gnu/packages/patches/xdotool-fix-makefile.patch               \
  gnu/packages/patches/xf86-video-ark-remove-mibstore.patch	\
  gnu/packages/patches/xf86-video-ast-remove-mibstore.patch	\
  gnu/packages/patches/xf86-video-geode-glibc-2.20.patch	\
  gnu/packages/patches/xf86-video-glint-remove-mibstore.patch	\
  gnu/packages/patches/xf86-video-i128-remove-mibstore.patch	\
  gnu/packages/patches/xf86-video-intel-compat-api.patch	\
  gnu/packages/patches/xf86-video-intel-glibc-2.20.patch	\
  gnu/packages/patches/xf86-video-mach64-glibc-2.20.patch	\
  gnu/packages/patches/xf86-video-nv-remove-mibstore.patch	\
  gnu/packages/patches/xf86-video-openchrome-glibc-2.20.patch	\
  gnu/packages/patches/xf86-video-tga-remove-mibstore.patch	\
  gnu/packages/patches/xfce4-panel-plugins.patch		\
  gnu/packages/patches/xfce4-session-fix-xflock4.patch		\
  gnu/packages/patches/xfce4-settings-defaults.patch		\
  gnu/packages/patches/xmodmap-asprintf.patch 			\
  gnu/packages/patches/zathura-plugindir-environment-variable.patch

MISC_DISTRO_FILES =				\
  gnu/packages/ld-wrapper.in

bootstrapdir = $(guilemoduledir)/gnu/packages/bootstrap
bootstrap_x86_64_linuxdir = $(bootstrapdir)/x86_64-linux
bootstrap_i686_linuxdir = $(bootstrapdir)/i686-linux
bootstrap_armhf_linuxdir = $(bootstrapdir)/armhf-linux
bootstrap_mips64el_linuxdir = $(bootstrapdir)/mips64el-linux

dist_bootstrap_x86_64_linux_DATA =		\
  gnu/packages/bootstrap/x86_64-linux/bash	\
  gnu/packages/bootstrap/x86_64-linux/mkdir	\
  gnu/packages/bootstrap/x86_64-linux/tar	\
  gnu/packages/bootstrap/x86_64-linux/xz

dist_bootstrap_i686_linux_DATA =		\
  gnu/packages/bootstrap/i686-linux/bash	\
  gnu/packages/bootstrap/i686-linux/mkdir	\
  gnu/packages/bootstrap/i686-linux/tar		\
  gnu/packages/bootstrap/i686-linux/xz

dist_bootstrap_armhf_linux_DATA =		\
  gnu/packages/bootstrap/armhf-linux/bash	\
  gnu/packages/bootstrap/armhf-linux/mkdir	\
  gnu/packages/bootstrap/armhf-linux/tar	\
  gnu/packages/bootstrap/armhf-linux/xz

dist_bootstrap_mips64el_linux_DATA =		\
  gnu/packages/bootstrap/mips64el-linux/bash	\
  gnu/packages/bootstrap/mips64el-linux/mkdir	\
  gnu/packages/bootstrap/mips64el-linux/tar	\
  gnu/packages/bootstrap/mips64el-linux/xz

# Big bootstrap binaries are not included in the tarball.  Instead, they
# are downloaded.
nodist_bootstrap_x86_64_linux_DATA =					\
  gnu/packages/bootstrap/x86_64-linux/guile-2.0.9.tar.xz
nodist_bootstrap_i686_linux_DATA =					\
  gnu/packages/bootstrap/i686-linux/guile-2.0.9.tar.xz
nodist_bootstrap_armhf_linux_DATA =					\
  gnu/packages/bootstrap/armhf-linux/guile-2.0.11.tar.xz
nodist_bootstrap_mips64el_linux_DATA =					\
  gnu/packages/bootstrap/mips64el-linux/guile-2.0.9.tar.xz

# Those files must remain executable, so they remain executable once
# imported into the store.
set-bootstrap-executable-permissions:
	chmod +x $(DESTDIR)$(bootstrapdir)/*/{bash,mkdir,tar,xz}

DISTCLEANFILES =				\
  $(nodist_bootstrap_x86_64_linux_DATA)		\
  $(nodist_bootstrap_i686_linux_DATA)		\
  $(nodist_bootstrap_armhf_linux_DATA)		\
  $(nodist_bootstrap_mips64el_linux_DATA)

# Method to download a file from an external source.
DOWNLOAD_FILE =								\
  GUILE_LOAD_COMPILED_PATH="$(top_builddir):$$GUILE_LOAD_COMPILED_PATH"	\
  $(GUILE) --no-auto-compile -L "$(top_builddir)" -L "$(top_srcdir)"	\
           "$(top_srcdir)/build-aux/download.scm"

gnu/packages/bootstrap/x86_64-linux/guile-2.0.9.tar.xz:
	$(AM_V_DL)$(MKDIR_P) `dirname "$@"`;	\
	$(DOWNLOAD_FILE) "$@"			\
	  "037b103522a2d0d7d69c7ffd8de683dfe5bb4b59c1fafd70b4ffd397fd2f57f0"
gnu/packages/bootstrap/i686-linux/guile-2.0.9.tar.xz:
	$(AM_V_DL)$(MKDIR_P) `dirname "$@"`;	\
	$(DOWNLOAD_FILE) "$@"			\
	  "b757cd46bf13ecac83fb8e955fb50096ac2d17bb610ca8eb816f29302a00a846"
gnu/packages/bootstrap/armhf-linux/guile-2.0.11.tar.xz:
	$(AM_V_DL)$(MKDIR_P) `dirname "$@"`;	\
	$(DOWNLOAD_FILE) "$@"			\
	  "e551d05d4d385d6706ab8d574856a087758294dc90ab4c06e70a157a685e23d6"
gnu/packages/bootstrap/mips64el-linux/guile-2.0.9.tar.xz:
	$(AM_V_DL)$(MKDIR_P) `dirname "$@"`;	\
	$(DOWNLOAD_FILE) "$@" 			\
	  "994680f0001346864aa2c2cc5110f380ee7518dcd701c614291682b8e948f73b"
